==> jun1_24.zip: zad2_c.php <==
<!DOCTYPE html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
        <style>
            *{
                box-sizing: border-box;
                color:coral;
            }
            div {
                width: 500px;
                height: 600px;
                margin: auto;
                position: relative;
                top: 100px;
                background-color: rgb(213, 246, 233);
                padding-left: 10px;
                padding-top: 10px;
            }
            img {
                width: 50px;
                height: 50px;
            }
            table{
                text-align: center;
            }
            input[type="submit"]{
                width: 150px;
                background-color: rgb(248, 236, 200);
                padding: 5px;
            }
        </style>
    </head>
    <body>
        <div>
        <h1>Uspesno ste narucili:</h1>
        <?php
            $artikli = explode(" ", $_POST['artikli']);
            echo "<ul>";
            foreach($artikli as $artikl){
                echo "<li><img src='slike/".$artikl.".png' alt='nema slike'></li>";
            }
        ?>
        <p>Podaci o kupcu:</p>
        Ime i prezime:<?php echo $_POST['ime']." ".$_POST['prezime'];?><br><br>
        Adresu:<?php echo $_POST['adresa'];?><br><br>
        Mesto:<?php echo $_POST['mesto'];?><br><br>
        Postanski broj:<?php echo $_POST['posta'];?><br><br>
        Broj telefona:<?php echo $_POST['telefon'];?><br><br>
       </body>
       </div>
</html>

==> jun2_24.zip: zad2_c.php <==
<!DOCTYPE html>
<html>
    <head>
        <meta http-equiv="Content-Type" content="text/html;charset=UTF-8">
        <style>
            *{
                box-sizing: border-box;
                color:coral;
            }
            div {
                width: 500px;
                height: 600px;
                margin: auto;
                position: relative;
                top: 100px;
                background-color: rgb(213, 246, 233);
                padding-left: 10px;
                padding-top: 10px;
            }
            img {
                width: 50px;
                height: 50px;
            }
            table{
                text-align: center;
            }
            input[type="submit"]{
                width: 150px;
                background-color: rgb(248, 236, 200);
                padding: 5px;
            }
        </style>
    </head>
    <body>
        <div>
        <h1>Uspesno ste narucili:</h1>
        <?php
            $solja = explode(" ", $_POST['solja']);
            $boja = explode(" ", $_POST['boja']);
            echo "<ul>";
            foreach($solja as $s){
                foreach($boja as $b)
                echo "<li><img src='slike/".$s.$b.".png' alt='nema slike'></li>";
            }
        ?>
        <p>Podaci o kupcu:</p>
        Ime i prezime:<?php echo $_POST['ime']." ".$_POST['prezime'];?><br><br>
        Adresu:<?php echo $_POST['adresa'];?><br><br>
        Mesto:<?php echo $_POST['mesto'];?><br><br>
        Postanski broj:<?php echo $_POST['posta'];?><br><br>
        Broj telefona:<?php echo $_POST['telefon'];?><br><br>
       </body>
       </div>
</html>
